@@ -20,6 +20,7 @@ void	GetDprsMessage()
 	len = recv(dprsSocket, DprsTemp, 500, 0);
 	if (len == 0) return;
 	DprsTemp[len] = 0x00;
+printf ("%s",DprsTemp);
 
 	msgstart = (char *)&DprsTemp;	
 	msglast = msgstart + len - 1;
@@ -106,6 +107,7 @@ next:
 Find:
 
 	memset (DprsMsgSrcCallSign, 0x20, 9);
+	if (k1 > 9) k1 = 9;
 	memcpy (DprsMsgSrcCallSign, msgstart, k1);
 
 	DprsMsgSend(dstpnt+12);
