@@ -16,7 +16,7 @@ struct	DPRSinfo{
 	unsigned char 			: 1;
 	unsigned char AutoReLink	: 1;
 	unsigned char AutoLink		: 1;
-	unsigned char ClientID		: 1;
+	unsigned char BeaconSend	: 1;
 	unsigned char 			: 1;
 	unsigned char DprsStrip		: 1;
 	unsigned char DprsSW 		: 1;
