@@ -30,7 +30,8 @@
 		   V00.24 Changed Config file
 	2014.02.21 V00.25 Added sending Aprs message to D-STAR rig
 	2014.02.23 V00.26 Changed from "APRS" to "DPRS" in config file
-	2014.03.05 V00.27 Bug fixed for GetDprsMessag
+	2014.03.05 V00.27 Bug fixed for GetDprsMessage
+	2014.03.05 V00.28 Bug fixed for GetDprsMessage
 */
 
 #include	"dsgwd_pi.h"
