@@ -2,13 +2,9 @@
 	Auther		Satoshi Yasuda	7m3tjz/ad6gz
 */
 
-#include <string.h>
-#include <errno.h>
-#include <stdio.h>
-#include <stdarg.h>
-#include <usb.h>
-#include "dsgwd_pi.h"
-#include "node.h"
+#include	<usb.h>
+#include 	"dsgwd_pi.h"
+#include 	"node.h"
 
 struct	usb_bus	*bus;
 struct	usb_bus	*busses;
